@@ -5,8 +5,8 @@
 #' @inheritParams geom_serialaxes
 #' @param quantiles numeric vector of probabilities with values in [0,1]. (Values up to 2e-14 outside that
 #' range are accepted and moved to the nearby endpoint.)
-#' @seealso \code{\link{geom_density_}}, \code{\link{geom_serialaxes}},
-#' \code{\link{geom_serialaxes_density}}, \code{\link{geom_serialaxes_hist}}
+#' @seealso \code{\link[ggmulti]{geom_density_}}, \code{\link[ggmulti]{geom_serialaxes}},
+#' \code{\link[ggmulti]{geom_serialaxes_density}}, \code{\link[ggmulti]{geom_serialaxes_hist}}
 #' @export
 #' @examples
 #' # lower quantile, median and upper quantile
@@ -76,15 +76,14 @@ GeomSerialaxesQuantile <- ggplot2::ggproto(
     data %>%
       ggplot2::flip_data(flip = flip) %>%
       dplyr::group_by_at(dplyr::vars(dplyr::any_of(c("PANEL", "y", accepted_aes)))) %>%
-      dplyr::summarise(x = stats::quantile(x, probs = params$quantiles)) %>%
-      dplyr::ungroup() %>%
+      dplyr::reframe(x = stats::quantile(x, probs = params$quantiles)) %>%
       pivot_group(vars = c("PANEL", accepted_aes),
                   flipped_aes = flip,
                   quantiles = params$quantiles) %>%
       as.data.frame() %>%
       ggplot2::flip_data(flip = flip)
   },
-  use_defaults = function(self, data, params = list(), modifiers = aes()) {
+  use_defaults = function(self, data, params = list(), modifiers = aes(), ...) {
 
     n <- dim(data)[1]
     uniGroup <- unique(data$group)
@@ -106,13 +105,13 @@ GeomSerialaxesQuantile <- ggplot2::ggproto(
       )
     }
 
-    ggplot2::ggproto_parent(ggplot2::GeomPath, self)$use_defaults(data, params, modifiers)
+    ggplot2::ggproto_parent(ggplot2::GeomPath, self)$use_defaults(data, params, modifiers, ...)
   },
   draw_panel = function(self, data, panel_params, coord, arrow = NULL,
                         quantiles = seq(0, 1, 0.25), lineend = "butt", linejoin = "round",
                         linemitre = 10, na.rm = FALSE) {
-    ggplot2::ggproto_parent(ggplot2::GeomPath, self)$draw_panel(data, panel_params, coord, arrow,
-                                                                lineend, linejoin, linemitre, na.rm)
+    ggplot2::ggproto_parent(ggplot2::GeomPath, self)$draw_panel(data = data, panel_params = panel_params, coord = coord, arrow = arrow,
+                                                                lineend = lineend, linejoin = linejoin, linemitre = linemitre, na.rm = na.rm)
   }
 )
 
