@@ -14,27 +14,27 @@ test_that("test position", {
                             y = x,
                             fill = Species))
   q <- p +
-    stat_hist_(adjust = 0.5,
+    stat_hist_(prop = 0.5,
                position = position_dodge2_(preserve = "single"))
   b <- ggplot_build(q)
   expect_true("PositionDodge2_" %in% class(b$plot$layers[[1]]$position))
 
   q <- p +
-    stat_hist_(adjust = 0.5,
+    stat_hist_(prop = 0.5,
                position = position_dodge_(preserve = "single"))
   b <- ggplot_build(q)
   expect_true("PositionDodge_" %in% class(b$plot$layers[[1]]$position))
 
   ### stack_
   q <- p +
-    stat_density_(adjust = 0.5,
+    stat_density_(prop = 0.5,
                   position = position_stack_(reverse = TRUE))
   b <- ggplot_build(q)
   expect_true("PositionStack_" %in% class(b$plot$layers[[1]]$position))
 
   ### identity_
   q <- p +
-    stat_density_(adjust = 0.5,
+    stat_density_(prop = 0.5,
                   position = position_identity_())
   b <- ggplot_build(q)
   expect_true("PositionIdentity_" %in% class(b$plot$layers[[1]]$position))
